# Examples

The [Time-Centric Calculations example](./time_centric.ipynb) shows how to work with time and produce past training examples and recent results for applying models.

The [Reddit example](./reddit.md) shows how to read and aggregate live messages from Reddit.

The [Bluesky Firehose example](./bluesky.md) shows how to read and aggregate messages from the Bluesky firehose.
This demonstrates how to use Kaskada to connect in real-time and parse messages as part of the query.

```{toctree}
:hidden:
:maxdepth: 2

time_centric
reddit
bluesky
```